Crate simploxide_core

Crate simploxide_core 

Starting from 0.4.0 this crate is repurposed to supply types shared between simploxide-ws-core and simploxide-ffi-core. Check the documentation of the corresponding crates for actual functionality

Structs

SimplexVersion
Parses SimpleX version numbers in the form MAJOR.MINOR.PATCH.HOTFIX.
VersionData
VersionInfo
A helper to parse version from SimpleX response

Constants

MAX_SUPPORTED_VERSION
MIN_SUPPORTED_VERSION